@@ -1,8 +1,29 @@
 /*
 
-SDL_gfxPrimitives: graphics primitives for SDL
+SDL_gfxPrimitives.h: graphics primitives for SDL
 
-LGPL (c) A. Schiffler
+Copyright (C) 2001-2013  Andreas Schiffler
+
+This software is provided 'as-is', without any express or implied
+warranty. In no event will the authors be held liable for any damages
+arising from the use of this software.
+
+Permission is granted to anyone to use this software for any purpose,
+including commercial applications, and to alter it and redistribute it
+freely, subject to the following restrictions:
+
+1. The origin of this software must not be misrepresented; you must not
+claim that you wrote the original software. If you use this software
+in a product, an acknowledgment in the product documentation would be
+appreciated but is not required.
+
+2. Altered source versions must be plainly marked as such, and must not be
+misrepresented as being the original software.
+
+3. This notice may not be removed or altered from any source
+distribution.
+
+Andreas Schiffler -- aschiffler at ferzkopp dot net
 
 */
 
@@ -14,7 +35,7 @@ LGPL (c) A. Schiffler
 #define M_PI	3.1415926535897932384626433832795
 #endif
 
-#include "SDL.h"
+#include <SDL.h>
 
 /* Set up for C function definitions, even when using C++ */
 #ifdef __cplusplus
@@ -25,12 +46,12 @@ extern "C" {
 
 #define SDL_GFXPRIMITIVES_MAJOR	2
 #define SDL_GFXPRIMITIVES_MINOR	0
-#define SDL_GFXPRIMITIVES_MICRO	22
+#define SDL_GFXPRIMITIVES_MICRO	26
 
 
 	/* ---- Function Prototypes */
 
-#if defined(WIN32) || defined(WIN64)
+#ifdef _MSC_VER
 #  if defined(DLL_EXPORT) && !defined(LIBSDL_GFX_DLL_IMPORT)
 #    define SDL_GFXPRIMITIVES_SCOPE __declspec(dllexport)
 #  else
