@@ -1,6 +1,6 @@
 ;;; misc-utils.scm --- grab bag of utility procs
 
-;; Copyright (C) 2004-2009, 2011, 2013 Thien-Thi Nguyen
+;; Copyright (C) 2004-2009, 2011, 2013, 2022 Thien-Thi Nguyen
 ;;
 ;; This is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 
 (define-module (sdl misc-utils)
   #:export (exact-truncate
+            exact-floor
             call-with-clip-rect
             rotate-square
             rectangle-closure
@@ -50,6 +51,11 @@
 (define (exact-truncate number)
   (inexact->exact (truncate number)))
 
+;; Return the exact floor (rounding to negative infinity) of @var{number}.
+;;
+(define (exact-floor number)
+  (inexact->exact (floor number)))
+
 ;; Set default clip rect to @var{rect}, call @var{thunk}, and restore it.
 ;; @var{thunk} is a procedure that takes no arguments.
 ;;
