@@ -1,7 +1,6 @@
 /* sdlevent.c --- SDL input handling for Guile
  *
- * Copyright (C) 2003, 2004, 2005, 2006, 2007,
- *   2009, 2011, 2013 Thien-Thi Nguyen
+ * Copyright (C) 2003-2007, 2009, 2011, 2013, 2015 Thien-Thi Nguyen
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,10 +12,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "guile-sdl.h"
@@ -38,15 +35,9 @@ static SCM mbut_enum;
 static SCM event_type_enum;
 #include "k/evtype.c"
 
-static SCM event_state_enum;
-#include "k/evstate.c"
-
 static SCM event_keysym_enum;
 #include "k/keysym.c"
 
-static SCM event_action_enum;
-#include "k/evaction.c"
-
 static SCM event_mb_flags;
 static SCM event_mod_flags;
 static SCM event_mask_flags;
@@ -434,109 +425,6 @@ If there are errors, return @code{#f}.
   return evqueue_do (&dd, n, mask);
 }
 
-PRIMPROC
-(peep_events, "peep-events", 4, 0, 0,
- (SCM events, SCM numevents, SCM action, SCM mask),
- doc: /***********
-NB: This procedure is obsoleted by @code{evqueue-add},
-@code{evqueue-peek} and @code{evqueue-get};
-it @strong{will be removed} after 2013-12-31.
-
-Manage the event queue, depending
-on @var{action} (@pxref{event-action enums}):
-
-@table @code
-@item SDL_ADDEVENT
-Add up to @var{numevents} (an integer) events from
-@var{events} (a list) to the back of the event queue.
-
-@item SDL_PEEKEVENT
-Return a count (number less than or equal to @var{numevents})
-of events at the front of the event queue that match @var{mask}
-(@pxref{event-mask flags}), without changing the queue.
-
-@item SDL_GETEVENT
-Act like for @code{SDL_PEEKEVENT} except return a list of
-matching events instead of a count, removing them from the queue.
-@end table  */)
-{
-#define FUNC_NAME s_peep_events
-  DECLINIT_SYM2NUM_CC (3, event_action_enum);
-  DECLINIT_SYM2NUM_CC (4, event_mask_flags);
-  SDL_Event *cevents = NULL;
-  SDL_eventaction caction;
-  int cnumevents, i, ret = -1;
-  Uint32 cmask;
-  SCM ls = SCM_BOOL_F;
-
-  ASSERT_LONG_COPY (numevents, 2);
-  caction = ENUM2LONG (3, action);
-
-  switch (caction)
-    {
-    case SDL_ADDEVENT:
-      /* Do two passes: first to validate argument types and consistency,
-         second to allocate the array and copy the events (ugh).  This will
-         most certainly be re-implemented w/ user-visible uniform vectors.  */
-      SCM_VALIDATE_LIST_COPYLEN (1, events, i);
-      if (cnumevents > i)
-        SCM_MISC_ERROR ("numevents greater than events length",
-                        SCM_EOL);
-      for (i = 0, ls = events;
-           i < cnumevents;
-           i++, ls = CDR (ls))
-        if (! EVENT_P (CAR (ls)))
-          break;
-      ASSERT_TYPE (i == cnumevents, events, 1, "list of SDL-Event");
-      cevents = ALLOCA_EVENTS (cnumevents);
-      for (i = 0, ls = events;
-           i < cnumevents;
-           i++, ls = CDR (ls))
-        cevents[i] = *(UNPACK_EVENT (CAR (ls)));
-      ret = SDL_PeepEvents (cevents, cnumevents, caction, 0);
-      break;
-
-    case SDL_GETEVENT:
-      cevents = ALLOCA_EVENTS (cnumevents);
-      /* fallthrough */
-
-    case SDL_PEEKEVENT:
-      cmask = FLAGS2ULONG (4, mask);
-      ret = SDL_PeepEvents (cevents, cnumevents, caction, cmask);
-      if (0 > ret)
-        SCM_MISC_ERROR ("badness", SCM_EOL);
-      if (cevents)
-        {
-          SDL_Event *cev; SCM ev;
-
-          ls = SCM_EOL;
-          for (i = ret - 1; -1 < i; i--)
-            {
-              cev = GCMALLOC_EVENT ();
-              *cev = cevents[i];
-              NEW_EVENT_X (ev, cev);
-              ls = CONS (ev, ls);
-            }
-        }
-      break;
-
-    default:
-      SCM_MISC_ERROR ("bad action", SCM_EOL);
-    }
-
-  switch (caction)
-    {
-    case SDL_ADDEVENT:
-    case SDL_PEEKEVENT:
-      RETURN_INT (ret);
-    case SDL_GETEVENT:
-      return ls;
-    default:
-      RETURN_UNSPECIFIED;
-    }
-#undef FUNC_NAME
-}
-
 PRIMPROC
 (poll_event, "poll-event", 0, 1, 0,
  (SCM event),
@@ -703,31 +591,6 @@ If @var{setting} is specified, set the handling of
 #undef FUNC_NAME
 }
 
-PRIMPROC
-(event_state, "event-state", 2, 0, 0,
- (SCM type, SCM state),
- doc: /***********
-NB: This procedure is obsoleted by @code{event-type-handling}
-and @strong{will be removed} after 2013-12-31.
-
-Set or query the state of event @var{type} (@pxref{event-type enums})
-processing, based on @var{state} (@pxref{event-state enums}).
-If @var{state} is @code{SDL_QUERY}, return the current state.
-If it is @code{SDL_IGNORE} or @code{SDL_ENABLE},
-disable or enable, respectively, internal event @var{type}
-processing and return @var{state}.  */)
-{
-#define FUNC_NAME s_event_state
-  DECLINIT_SYM2NUM_CC   (1, event_type_enum);
-  int ctype = ENUM2LONG (1, type);
-  DECLINIT_SYM2NUM_CC    (2, event_state_enum);
-  int cstate = ENUM2LONG (2, state);
-  int ret = SDL_EventState (ctype, cstate);
-
-  return btw->long2enum (ret, event_state_enum);
-#undef FUNC_NAME
-}
-
 PRIMPROC
 (enable_unicode, "enable-unicode", 0, 1, 0,
  (SCM enable_p),
@@ -818,72 +681,6 @@ only the key modifier flags.  */)
 
 typedef Uint8 SDLCALL (*getmouse_sdl_fn) (int *x, int *y);
 
-DECLARE_SIMPLE_SYM (state);
-DECLARE_SIMPLE_SYM (x);
-DECLARE_SIMPLE_SYM (y);
-
-static SCM
-getmouse (const char *FUNC_NAME, SCM symbolic, getmouse_sdl_fn fn)
-{
-  unsigned long buttons;
-  int x, y;
-
-  UNBOUND_MEANS_FALSE (symbolic);
-
-  buttons = fn (&x, &y);
-  return LIST3
-    (CONS (SYM (state),
-           EXACTLY_FALSEP (symbolic)
-           ? NUM_ULONG (buttons)
-           : (buttons
-              ? btw->ulong2flags (buttons, event_mb_flags)
-              : SCM_EOL)),
-     CONS (SYM (x), NUM_LONG (x)),
-     CONS (SYM (y), NUM_LONG (y)));
-}
-
-PRIMPROC
-(get_mouse_state, "get-mouse-state", 0, 1, 0,
- (SCM symbolic),
- doc: /***********
-NB: This procedure is obsoleted by @code{mouse-bxy}
-and @strong{will be removed} after 2013-12-31.
-
-Return the current state of the mouse as an alist with
-symbolic keys: @code{state}, @code{x} and @code{y}.
-Normally, all values are integers.
-However, if optional arg @var{symbolic} is non-@code{#f},
-the @code{state} value is instead a (possibly empty)
-list of symbols of the set:
-
-@example
-left middle right
-wheel-up wheel-down
-x1 x2
-@end example  */)
-{
-  return getmouse (s_get_mouse_state,
-                   symbolic,
-                   SDL_GetMouseState);
-}
-
-PRIMPROC
-(get_relative_mouse_state, "get-mouse-relative-state", 0, 1, 0,
- (SCM symbolic),
- doc: /***********
-NB: This procedure is obsoleted by @code{mouse-bxy}
-and @strong{will be removed} after 2013-12-31.
-
-Return the current relative state of the mouse as an alist
-with symbolic keys: @code{state}, @code{x} and @code{y}.
-Optional arg @var{symbolic} has the same effect as
-for @code{get-mouse-state}.  */)
-{
-  return getmouse (s_get_relative_mouse_state,
-                   symbolic,
-                   SDL_GetRelativeMouseState);
-}
-
 PRIMPROC
 (button_p, "button?", 1, 0, 0,
  (SCM mask),
@@ -893,7 +690,7 @@ otherwise @code{#f}.
 @var{mask} is a symbol or a list of symbols from the set returned
 by @code{get-mouse-state}.
 
-For backward compatability, @var{mask} can also be the (integer)
+For backward compatibility, @var{mask} can also be the (integer)
 logior of the buttons, using mapping:
 
 @example
@@ -988,8 +785,6 @@ gsdl_init_event (void)
     kp_init_t allp[] = {
       { &event_type_enum, &evtype_kp },
       { &event_keysym_enum, &keysym_kp },
-      { &event_action_enum, &evaction_kp },
-      { &event_state_enum, &evstate_kp },
       { &mbut_enum, &mbut_kp },
       { &updn_enum, &updn_kp },
       { &active_enum, &active_kp }
@@ -1009,7 +804,6 @@ gsdl_init_event (void)
     REGISTER_KF_V (allf);
   }
 
-  btw->event_state_enum = event_state_enum;
   btw->updn_enum = updn_enum;
 
   efi.proc = SCM_BOOL_F;
